import { useEffect, useState } from "react";
import PlantDetails from "../components/PlantDetails";
import { Plant } from "../utils/schemas";
import useGrowbrosFetcher from "../utils/useGrowbrosFetcher";
import { IBackendConnector } from "../utils/IBackendConnector";
import PlantsOverview from "../components/PlantsOverview";
import DropDownFilter from "../components/DropDownFilter";

function Wunschliste() {
  const [plants, setPlantsInWishlist] = useState<Plant[]>([]);
  console.log(plants);
  const [error, setError] = useState({});
  const [currentSort, setCurrentSort] = useState<string>("");

  const bc: IBackendConnector = useGrowbrosFetcher();

  useEffect(() => {
    (async () => {
      const result = await bc.getWishlistEntries(currentSort);
      if (result.err) {
        setError(result.err);
      } else {
        setPlantsInWishlist(result.value!);
      }
    })();
  }, [currentSort]);

  const handleSortOptions = async (selectedOption: string) => {
    switch (selectedOption) {
      case "neueste zuerst":
        setCurrentSort("createdAt");
        break;
      case "als nächstes anpflanzbar":
        setCurrentSort("plantDate");
        break;
      case "als nächstes erntbar":
        setCurrentSort("currentPlantable");
        break;
      default:
        setCurrentSort("");
    }
  };

  return (
    <>
      <DropDownFilter
        filterOnChange={handleSortOptions}
        options={[
          "neueste zuerst",
          "als nächstes anpflanzbar",
          "gerade anpflanzbar",
        ]}
        topic={"Sortierung der Pflanzen in der Wunschliste"}
      />
      <PlantsOverview plants={plants} />
    </>
  );
}

export default Wunschliste;
